@@ -179,7 +179,7 @@ class ImportScanSerializer(Schema):
     product_name = fields.Str(required=False)
     engagement_name = fields.Str(required=True)
     engagement_end_date = fields.Str(required=False)
-    source_code_management_uri = fields.Str(required=False)
+    source_code_management_uri = fields.Str(required=False, load_default=None)
     engagement = fields.Int(required=False)
     auto_create_context = fields.Str(required=False, load_default="true")
     deduplication_on_engagement = fields.Str(required=False)
@@ -202,7 +202,7 @@ class ImportScanSerializer(Schema):
     test_title = fields.Str(required=False)
     product_description = fields.Str(required=False)
     create_finding_groups_for_all_findings = fields.Str(required=False)
-    tool_sonarqube_configuration = fields.Int(required=False, load_default=1)
+    tool_sonarqube_configuration = fields.Int(required=False)
     tool_scm_configuration = fields.Int(required=False)
     code_app = fields.Str(required=False)
     # defect-dojo credential
